confidant-client
================

A client for [confidant](https://lyft.github.io).

Docs
----

* [Installation](https://lyft.github.io/confidant/install)
* [Configuration](https://lyft.github.io/confidant/configuration)
* [Usage](https://lyft.github.io/confidant/using_confidant)
* [Contribution](https://lyft.github.io/confidant/contributing)

Reporting security vulnerabilities
----------------------------------

If you've found a vulnerability or a potential vulnerability in Confidant
please let us know at security@lyft.com. We'll send a confirmation email to
acknowledge your report, and we'll send an additional email when we've
identified the issue positively or negatively.

Getting support or asking questions
-----------------------------------

We have a mailing list for discussion, and a low volume list for announcements:

* https://groups.google.com/forum/#!forum/confidant-users
* https://groups.google.com/forum/#!forum/confidant-announce

We also have an IRC channel on freenode and a Gitter channel:

* [#confidant](http://webchat.freenode.net/?channels=confidant)
* [lyft/confidant on Gitter](https://gitter.im/lyft/confidant)

Feel free to drop into either Gitter or the IRC channel for any reason, even
if just to chat. It doesn't matter which one you join, the messages are sync'd
between the two.
